package com.yiqi.admin.controller.order;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.order.domain.OrderGoodsItem;
import com.yiqi.order.service.IOrderGoodsItemService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 商品订单商品信息Controller
 *
 * @author ruoyi
 * @date 2023-12-06
 */
@Api(tags = "管理后台 - 商品订单商品信息")
@RestController
@RequestMapping(UrlConstants.managerApi + "/order/goodsItem")
public class OrderGoodsItemController extends BaseController {
    @Autowired
    private IOrderGoodsItemService orderGoodsItemService;


    //<editor-folder desc="基础函数">
    /**
     * 查询商品订单商品信息列表
     */
//    @PreAuthorize("@ss.hasPermi('order:goodsItem:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询商品订单商品信息列表")
    public TableDataInfo list(OrderGoodsItem orderGoodsItem) {
        startPage();
        List<OrderGoodsItem> list = orderGoodsItemService.selectOrderGoodsItemList(orderGoodsItem);
        return getDataTable(list);
    }

    /**
     * 导出商品订单商品信息列表
     */
//    @PreAuthorize("@ss.hasPermi('order:goodsItem:export')")
    @Log(title = "商品订单商品信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出商品订单商品信息列表")
    public void export(HttpServletResponse response, OrderGoodsItem orderGoodsItem) {
        List<OrderGoodsItem> list = orderGoodsItemService.selectOrderGoodsItemList(orderGoodsItem);
        ExcelUtil<OrderGoodsItem> util = new ExcelUtil<OrderGoodsItem>(OrderGoodsItem. class);
        util.exportExcel(response, list, "商品订单商品信息数据");
    }

    /**
     * 获取商品订单商品信息详细信息
     */
//    @PreAuthorize("@ss.hasPermi('order:goodsItem:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取商品订单商品信息详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(orderGoodsItemService.selectOrderGoodsItemById(id));
    }

    /**
     * 新增商品订单商品信息
     */
//    @PreAuthorize("@ss.hasPermi('order:goodsItem:add')")
    @Log(title = "商品订单商品信息", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增商品订单商品信息")
    public AjaxResult add(@RequestBody OrderGoodsItem orderGoodsItem) {
        orderGoodsItem.setCreateById(getUserId());
        orderGoodsItem.setCreateBy(getUsername());
        return toAjax(orderGoodsItemService.insertOrderGoodsItem(orderGoodsItem));
    }

    /**
     * 修改商品订单商品信息
     */
//    @PreAuthorize("@ss.hasPermi('order:goodsItem:edit')")
    @Log(title = "商品订单商品信息", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改商品订单商品信息")
    public AjaxResult edit(@RequestBody OrderGoodsItem orderGoodsItem) {
        orderGoodsItem.setUpdateById(getUserId());
        orderGoodsItem.setUpdateBy(getUsername());
        return toAjax(orderGoodsItemService.updateOrderGoodsItem(orderGoodsItem));
    }

    /**
     * 删除商品订单商品信息
     */
//    @PreAuthorize("@ss.hasPermi('order:goodsItem:remove')")
    @Log(title = "商品订单商品信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除商品订单商品信息")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(orderGoodsItemService.deleteOrderGoodsItemByIds(ids));
    }


    //</editor-folder>
}
